The facets summary module implements to switch to limit its rendering only when the facet source is rendered as processors.
That causes to build and populate results on the targeted facets first because that happens before any processor is executed.

The solution is to introduce a facet summary property like we have it for facets.

In addition the check for that property should happen as soon as possible and the result has to be cached.

This affects all facets versions.

Comments

mkalkbrenner created an issue. See original summary.

mkalkbrenner’s picture

Issue summary: View changes
Status: Active » Needs review
Issue tags: +Needs tests
StatusFileSize
new12.73 KB

Here's a patch. For sure some tests will fail now.

mkalkbrenner’s picture

StatusFileSize
new13.16 KB

forgot handling the new property in the submit handler

mkalkbrenner’s picture

StatusFileSize
new7.83 KB
new20.96 KB
mkalkbrenner’s picture

StatusFileSize
new21.15 KB

  • mkalkbrenner committed bda7e94 on 3.0.x
    Issue #3322928 by mkalkbrenner: Facets summary performance issues
    
mkalkbrenner’s picture

Status: Needs review » Fixed

  • mkalkbrenner committed 73d6673 on 3.0.x
    Issue #3322928 by mkalkbrenner: Facets summary performance issues
    

Status: Fixed » Closed (fixed)

Automatically closed - issue fixed for 2 weeks with no activity.